% This Matlab .m file solves the six compartment model posed in my
% "Solving the Overall Balance Equations" handout.  This file uses an
% include file (compartments.m) to define mnemonic array indices and 
% problem specific values. It also uses the deriv6c.m file that returns 
% an array of concentration derivatives with respect to time.
%
% Good input values to try are: 0:.1:6 for the time span and 10.0 grams for the 
% bolus size.
%
% File: body7c.m
% Written by: Dr. C. S. Tritt
% Version: 0.1
% Last updated: 12/11/05

% Define problem specific indices and values by including the compartments.m file.

compartments

% Get user input and define the initial conditions for the problem.
% For non-interactive operation, comment out the input lines and define the Tspan
% and Bolus before running this program.

Tspanhr = input('Enter time span in hours.  Format is [initial:step:final]: ');
Tspan = Tspanhr * 3600; % Convert hours to seconds.
Bolusg = input('Enter bolus size in grams: ');
Bolus = Bolusg*1000; % Convert g's to mg's.
c = zeros(NumCpmts,1); % Create and initialize column vector of concentrations (mg/l).
c(PL) = Bolus/v(PL); % mg/l 

% Set ODE solver options and solve the problem.

odeoptns = odeset('AbsTol', 0.05);
[Tcalc, Ccalc] = ODE45('deriv7c', Tspan, c, odeoptns);

% Display the maximum drug concentration in the typical tissue cells.

maxes = max(Ccalc);
disp('Maximum drug concentration in the typical tissue cells = ');
disp(maxes(TC));

% Plot results.

Tplot = Tcalc / 3600;
plot(Tplot, Ccalc);
axis([0 6 0 400]); % Clip long times and high concentrations.
legend('show');
xlabel('Time (hours)');
ylabel('Concentration (mg/l)');
title('Seven Compartment Model');

% Combine Tplot and Ccalc matrices and save the result in tab separated ASCII form.
% for import into Quattro Pro, etc.

OutData = [ Tplot Ccalc ];
save 'body7c.txt' OutData -ascii -tabs;