% This .m file contains indices and constants for the body7c.m/deriv7c.m ODE problem
% files.  See body7c.m for more information.

% File: compartments.m
% Written by: C. S. Tritt, Ph.D.
% Last updated: 1/7/05
% Version 0.1

% Compartment indices and constants.

PL = 1; % Plasma
BC = 2; % Blood cells
LF = 3; % Lymph and interstial fluid
DF = 4; % Dense tissue fluid
TC = 5; % Typical lean cells
DC = 6; % Dense cells
FC = 7; % Fat cells
NumCpmts = 7; % Number of compartments
v = [ 3.0, 2.4, 7.4, 3.0, 10.3, 6.0, 4.5 ]; % liters

% Mass transport indices and constants.

PL_BC = 1; % Plasma to cells
PL_TF = 2; % Plasma to lymph and interstial fluids
TF_DF = 3; % Lymph and interstial fluids to dense tissue fluid
TF_TC = 4; % Lymph and interstial fluids to lean cells
DF_DC = 5; % Dense fluid to dense cells
TF_FC = 6; % Lymph and interstial fluids to fat cells
NumTrans = 6; % Number of transport connections
a = [ 0.020, 0.012, 0.0050, 0.0055, 0.0040, 0.0035 ]; % Areas*U's (l/s)

% Michaelis-Menten kinetics indices and constants.

B = 1; % Red blood cells
T = 2; % Ordinary tissues cells
D = 3; % Dense tissue cells
k = [ 50.0, 50.0, 50.0 ]; % Half maximum concentration (mg/l)
m = [ 0.015, 0.025, 0.0050 ]; % Maximum rate ((mg/s)/l)

% Other constants.

f = 0.040; % Renal filtration fraction
p = 0.01; % Renal plasma flow (l/s)
Rin = 0.0; % Infusion rate (mg/s)
RSfc = 5.0; % Relatively solubity in fat cells.