function dCdt = deriv7c(t, c)
%
% This is the derivatives function required by the Matlab ODE 
% solvers for a particular 7 compartment model of the body.  It uses
% compartments.m and is used (indirectly) by body7c.m.  See these files
% for more information.

% File: deriv7c.m
% Written by: Dr. C. S. Tritt
% Version: 0.1
% Last updated: 1/7/05

% Define problem specific indexes and values.

compartments

% Predefine a column vector.

dCdt = zeros(NumCpmts,1);

% Calculate derivatives ((mg/l)/s).

dCdt(PL) = (Rin - a(PL_BC)*(c(PL)-c(BC)) -  a(PL_TF)*(c(PL)-c(LF)) - f*p*c(PL))/v(PL); 
dCdt(BC) = a(PL_BC)*(c(PL)-c(BC))/v(BC) - m(B)*c(BC)/(k(B) + c(BC));
dCdt(LF) = (a(PL_TF)*(c(PL)-c(LF)) - a(TF_DF)*(c(LF)-c(DF)) - a(TF_TC)*(c(LF)-c(TC)))/v(LF);
dCdt(DF) = (a(TF_DF)*(c(LF)-c(DF)) - a(DF_DC)*(c(DF)-c(DC)))/v(DF);
dCdt(TC) = a(TF_TC)*(c(LF)-c(TC))/v(TC) - m(T)*c(TC)/(k(T) + c(TC));
dCdt(DC) = a(DF_DC)*(c(DF)-c(DC))/v(DC) - m(D)*c(DC)/(k(D) + c(DC));
dCdt(FC) = a(TF_FC)*(c(LF)-c(FC)/RSfc)/v(FC);

return;